@@ -140,6 +140,7 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0x0195] = 0x01f6;
         table_map[0x0199] = 0x0198;
         table_map[0x019a] = 0x023d;
+        table_map[0x019b] = 0xa7dc;
         table_map[0x019e] = 0x0220;
         table_map[0x01a1] = 0x01a0;
         table_map[0x01a3] = 0x01a2;
@@ -230,6 +231,7 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0x0260] = 0x0193;
         table_map[0x0261] = 0xa7ac;
         table_map[0x0263] = 0x0194;
+        table_map[0x0264] = 0xa7cb;
         table_map[0x0265] = 0xa78d;
         table_map[0x0266] = 0xa7aa;
         table_map[0x0268] = 0x0197;
@@ -566,6 +568,7 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0x1c86] = 0x042a;
         table_map[0x1c87] = 0x0462;
         table_map[0x1c88] = 0xa64a;
+        table_map[0x1c8a] = 0x1c89;
         table_map[0x1d79] = 0xa77d;
         table_map[0x1d7d] = 0x2c63;
         table_map[0x1d8e] = 0xa7c6;
@@ -1089,9 +1092,11 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0xa7c3] = 0xa7c2;
         table_map[0xa7c8] = 0xa7c7;
         table_map[0xa7ca] = 0xa7c9;
+        table_map[0xa7cd] = 0xa7cc;
         table_map[0xa7d1] = 0xa7d0;
         table_map[0xa7d7] = 0xa7d6;
         table_map[0xa7d9] = 0xa7d8;
+        table_map[0xa7db] = 0xa7da;
         table_map[0xa7f6] = 0xa7f5;
         table_map[0xab53] = 0xa7b3;
         table_map[0xab70] = 0x13a0;
@@ -1362,6 +1367,28 @@ TEST_CASE("1. unicode to upper", "[detail]")
         table_map[0x10cf0] = 0x10cb0;
         table_map[0x10cf1] = 0x10cb1;
         table_map[0x10cf2] = 0x10cb2;
+        table_map[0x10d70] = 0x10d50;
+        table_map[0x10d71] = 0x10d51;
+        table_map[0x10d72] = 0x10d52;
+        table_map[0x10d73] = 0x10d53;
+        table_map[0x10d74] = 0x10d54;
+        table_map[0x10d75] = 0x10d55;
+        table_map[0x10d76] = 0x10d56;
+        table_map[0x10d77] = 0x10d57;
+        table_map[0x10d78] = 0x10d58;
+        table_map[0x10d79] = 0x10d59;
+        table_map[0x10d7a] = 0x10d5a;
+        table_map[0x10d7b] = 0x10d5b;
+        table_map[0x10d7c] = 0x10d5c;
+        table_map[0x10d7d] = 0x10d5d;
+        table_map[0x10d7e] = 0x10d5e;
+        table_map[0x10d7f] = 0x10d5f;
+        table_map[0x10d80] = 0x10d60;
+        table_map[0x10d81] = 0x10d61;
+        table_map[0x10d82] = 0x10d62;
+        table_map[0x10d83] = 0x10d63;
+        table_map[0x10d84] = 0x10d64;
+        table_map[0x10d85] = 0x10d65;
         table_map[0x118c0] = 0x118a0;
         table_map[0x118c1] = 0x118a1;
         table_map[0x118c2] = 0x118a2;
